==> haskell-sha-1.6.4.4-20-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 SHA
version:              1.6.4.4
visibility:           public
id:                   SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
key:                  SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
license:              BSD-3-Clause
maintainer:
    Adam Wick <awick@galois.com>,
    Raphael Javaux <raphaeljavaux@gmail.com>

author:               Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
stability:            stable
synopsis:
    Implementations of the SHA suite of message digest functions

description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.

category:             Cryptography, Codec
abi:                  5840f5dc64637eea68ba022fc997da8a
exposed:              True
exposed-modules:      Data.Digest.Pure.SHA
import-dirs:          /usr/lib/ghc-9.2.8/site-local/SHA-1.6.4.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/SHA-1.6.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sha
hs-libraries:         HSSHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
depends:
    array-0.5.4.0 base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0

haddock-interfaces:   /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html:         /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sha-1.6.4.4-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 SHA
version:              1.6.4.4
visibility:           public
id:                   SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
key:                  SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
license:              BSD-3-Clause
maintainer:
    Adam Wick <awick@galois.com>,
    Raphael Javaux <raphaeljavaux@gmail.com>

author:               Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
stability:            stable
synopsis:
    Implementations of the SHA suite of message digest functions

description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.

category:             Cryptography, Codec
abi:                  221ff1403748b9e679606f91ea030f33
exposed:              True
exposed-modules:      Data.Digest.Pure.SHA
import-dirs:          /usr/lib/ghc-9.4.8/site-local/SHA-1.6.4.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/SHA-1.6.4.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/SHA-1.6.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sha
hs-libraries:         HSSHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
depends:
    array-0.5.4.0 base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html:         /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
